You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@hive.apache.org by br...@apache.org on 2013/10/05 05:16:50 UTC

svn commit: r1529381 - in /hive/branches/maven: ./ ant/ beeline/ cli/ cli/src/test/org/apache/hadoop/hive/cli/ common/ common/src/java/org/apache/hive/common/util/ common/src/test/org/apache/hadoop/hive/conf/ common/src/test/resources/ contrib/ data/co...

Author: brock
Date: Sat Oct  5 03:16:48 2013
New Revision: 1529381

URL: http://svn.apache.org/r1529381
Log:
HIVE-5334 - Milestone 3: Some tests pass under maven

Added:
    hive/branches/maven/common/src/java/org/apache/hive/common/util/HiveTestUtils.java
    hive/branches/maven/data/conf/hive-log4j-new.properties
    hive/branches/maven/data/conf/hive-site-new.xml
Modified:
    hive/branches/maven/ant/pom.xml
    hive/branches/maven/beeline/pom.xml
    hive/branches/maven/cli/pom.xml
    hive/branches/maven/cli/src/test/org/apache/hadoop/hive/cli/TestCliDriverMethods.java
    hive/branches/maven/common/pom.xml
    hive/branches/maven/common/src/test/org/apache/hadoop/hive/conf/TestHiveConf.java
    hive/branches/maven/common/src/test/org/apache/hadoop/hive/conf/TestHiveLogging.java
    hive/branches/maven/common/src/test/resources/hive-exec-log4j-test.properties
    hive/branches/maven/common/src/test/resources/hive-log4j-test.properties
    hive/branches/maven/contrib/pom.xml
    hive/branches/maven/hbase-handler/pom.xml
    hive/branches/maven/hcatalog/core/pom-new.xml
    hive/branches/maven/hcatalog/hcatalog-pig-adapter/pom-new.xml
    hive/branches/maven/hcatalog/pom-new.xml
    hive/branches/maven/hcatalog/server-extensions/pom-new.xml
    hive/branches/maven/hcatalog/storage-handlers/hbase/pom-new.xml
    hive/branches/maven/hcatalog/webhcat/java-client/pom-new.xml
    hive/branches/maven/hcatalog/webhcat/svr/pom-new.xml
    hive/branches/maven/hwi/pom.xml
    hive/branches/maven/itests/pom.xml
    hive/branches/maven/jdbc/pom.xml
    hive/branches/maven/maven-rollback.sh
    hive/branches/maven/maven-rollforward.sh
    hive/branches/maven/metastore/pom.xml
    hive/branches/maven/pom.xml
    hive/branches/maven/ql/pom.xml
    hive/branches/maven/ql/src/java/org/apache/hadoop/hive/ql/exec/mr/ExecDriver.java
    hive/branches/maven/serde/pom.xml
    hive/branches/maven/service/pom.xml
    hive/branches/maven/shims/0.20/pom.xml
    hive/branches/maven/shims/0.20S/pom.xml
    hive/branches/maven/shims/0.23/pom.xml
    hive/branches/maven/shims/common-secure/pom.xml
    hive/branches/maven/shims/common/pom.xml
    hive/branches/maven/shims/pom.xml
    hive/branches/maven/shims/src/assembly/uberjar.xml
    hive/branches/maven/testutils/pom.xml

Modified: hive/branches/maven/ant/pom.xml
URL: http://svn.apache.org/viewvc/hive/branches/maven/ant/pom.xml?rev=1529381&r1=1529380&r2=1529381&view=diff
==============================================================================
--- hive/branches/maven/ant/pom.xml (original)
+++ hive/branches/maven/ant/pom.xml Sat Oct  5 03:16:48 2013
@@ -19,7 +19,7 @@
   <parent>
     <groupId>org.apache.hive</groupId>
     <artifactId>hive</artifactId>
-    <version>0.13.0-SNAPSHOT</version>
+    <version>0.99.0-SNAPSHOT</version>
     <relativePath>../pom.xml</relativePath>
   </parent>
 

Modified: hive/branches/maven/beeline/pom.xml
URL: http://svn.apache.org/viewvc/hive/branches/maven/beeline/pom.xml?rev=1529381&r1=1529380&r2=1529381&view=diff
==============================================================================
--- hive/branches/maven/beeline/pom.xml (original)
+++ hive/branches/maven/beeline/pom.xml Sat Oct  5 03:16:48 2013
@@ -19,7 +19,7 @@
   <parent>
     <groupId>org.apache.hive</groupId>
     <artifactId>hive</artifactId>
-    <version>0.13.0-SNAPSHOT</version>
+    <version>0.99.0-SNAPSHOT</version>
     <relativePath>../pom.xml</relativePath>
   </parent>
 

Modified: hive/branches/maven/cli/pom.xml
URL: http://svn.apache.org/viewvc/hive/branches/maven/cli/pom.xml?rev=1529381&r1=1529380&r2=1529381&view=diff
==============================================================================
--- hive/branches/maven/cli/pom.xml (original)
+++ hive/branches/maven/cli/pom.xml Sat Oct  5 03:16:48 2013
@@ -19,7 +19,7 @@
   <parent>
     <groupId>org.apache.hive</groupId>
     <artifactId>hive</artifactId>
-    <version>0.13.0-SNAPSHOT</version>
+    <version>0.99.0-SNAPSHOT</version>
     <relativePath>../pom.xml</relativePath>
   </parent>
 

Modified: hive/branches/maven/cli/src/test/org/apache/hadoop/hive/cli/TestCliDriverMethods.java
URL: http://svn.apache.org/viewvc/hive/branches/maven/cli/src/test/org/apache/hadoop/hive/cli/TestCliDriverMethods.java?rev=1529381&r1=1529380&r2=1529381&view=diff
==============================================================================
--- hive/branches/maven/cli/src/test/org/apache/hadoop/hive/cli/TestCliDriverMethods.java (original)
+++ hive/branches/maven/cli/src/test/org/apache/hadoop/hive/cli/TestCliDriverMethods.java Sat Oct  5 03:16:48 2013
@@ -170,9 +170,9 @@ public class TestCliDriverMethods extend
 
     try {
       new FakeCliDriver().run(args);
-      assertTrue(dataOut.toString().contains("test message"));
-      assertTrue(dataErr.toString().contains("Hive history file="));
-      assertTrue(dataErr.toString().contains("File: fakeFile is not a file."));
+      assertTrue(dataOut.toString(), dataOut.toString().contains("test message"));
+      assertTrue(dataErr.toString(), dataErr.toString().contains("Hive history file="));
+      assertTrue(dataErr.toString(), dataErr.toString().contains("File: fakeFile is not a file."));
       dataOut.reset();
       dataErr.reset();
 

Modified: hive/branches/maven/common/pom.xml
URL: http://svn.apache.org/viewvc/hive/branches/maven/common/pom.xml?rev=1529381&r1=1529380&r2=1529381&view=diff
==============================================================================
--- hive/branches/maven/common/pom.xml (original)
+++ hive/branches/maven/common/pom.xml Sat Oct  5 03:16:48 2013
@@ -19,7 +19,7 @@
   <parent>
     <groupId>org.apache.hive</groupId>
     <artifactId>hive</artifactId>
-    <version>0.13.0-SNAPSHOT</version>
+    <version>0.99.0-SNAPSHOT</version>
     <relativePath>../pom.xml</relativePath>
   </parent>
 
@@ -113,5 +113,47 @@
         <directory>${basedir}/src/test/resources</directory>
       </testResource>
     </testResources>
+    <plugins>
+      <plugin>
+        <groupId>org.apache.maven.plugins</groupId>
+        <artifactId>maven-antrun-plugin</artifactId>
+        <executions>
+          <execution>
+            <id>generate-version-annotation</id>
+            <phase>generate-sources</phase>
+            <configuration>
+              <target>
+                <exec executable="bash" failonerror="true">
+                  <arg value="${basedir}/src/scripts/saveVersion.sh"/>
+                  <arg value="${project.version}"/>
+                  <arg value="${basedir}/src"/>
+                </exec>
+              </target>
+            </configuration>
+            <goals>
+              <goal>run</goal>
+            </goals>
+          </execution>
+        </executions>
+      </plugin>
+      <plugin>
+        <groupId>org.codehaus.mojo</groupId>
+        <artifactId>build-helper-maven-plugin</artifactId>
+        <executions>
+          <execution>
+            <id>add-source</id>
+            <phase>generate-sources</phase>
+            <goals>
+              <goal>add-source</goal>
+            </goals>
+            <configuration>
+              <sources>
+                <source>src/gen</source>
+              </sources>
+            </configuration>
+          </execution>
+        </executions>
+      </plugin>
+    </plugins>
   </build>
 </project>

Added: hive/branches/maven/common/src/java/org/apache/hive/common/util/HiveTestUtils.java
URL: http://svn.apache.org/viewvc/hive/branches/maven/common/src/java/org/apache/hive/common/util/HiveTestUtils.java?rev=1529381&view=auto
==============================================================================
--- hive/branches/maven/common/src/java/org/apache/hive/common/util/HiveTestUtils.java (added)
+++ hive/branches/maven/common/src/java/org/apache/hive/common/util/HiveTestUtils.java Sat Oct  5 03:16:48 2013
@@ -0,0 +1,37 @@
+/**
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+
+package org.apache.hive.common.util;
+
+import java.net.URL;
+
+import org.apache.hadoop.hive.common.classification.InterfaceAudience;
+import org.apache.hadoop.hive.common.classification.InterfaceStability;
+
+@InterfaceAudience.Private
+@InterfaceStability.Unstable
+public class HiveTestUtils {
+
+  public static String getFileFromClasspath(String name) {
+    URL url = ClassLoader.getSystemResource(name);
+    if (url == null) {
+      throw new IllegalArgumentException("Could not find " + name);
+    }
+    return url.getPath();
+  }
+}

Modified: hive/branches/maven/common/src/test/org/apache/hadoop/hive/conf/TestHiveConf.java
URL: http://svn.apache.org/viewvc/hive/branches/maven/common/src/test/org/apache/hadoop/hive/conf/TestHiveConf.java?rev=1529381&r1=1529380&r2=1529381&view=diff
==============================================================================
--- hive/branches/maven/common/src/test/org/apache/hadoop/hive/conf/TestHiveConf.java (original)
+++ hive/branches/maven/common/src/test/org/apache/hadoop/hive/conf/TestHiveConf.java Sat Oct  5 03:16:48 2013
@@ -22,6 +22,7 @@ import junit.framework.TestCase;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.Path;
 import org.apache.hadoop.hive.conf.HiveConf.ConfVars;
+import org.apache.hive.common.util.HiveTestUtils;
 
 
 /**
@@ -33,8 +34,7 @@ import org.apache.hadoop.hive.conf.HiveC
 public class TestHiveConf extends TestCase {
 
   public void testHiveSitePath() throws Exception {
-    String expectedPath =
-        new Path(System.getProperty("test.build.resources") + "/hive-site.xml").toUri().getPath();
+    String expectedPath = HiveTestUtils.getFileFromClasspath("hive-site.xml");
     assertEquals(expectedPath, new HiveConf().getHiveSiteLocation().getPath());
   }
 

Modified: hive/branches/maven/common/src/test/org/apache/hadoop/hive/conf/TestHiveLogging.java
URL: http://svn.apache.org/viewvc/hive/branches/maven/common/src/test/org/apache/hadoop/hive/conf/TestHiveLogging.java?rev=1529381&r1=1529380&r2=1529381&view=diff
==============================================================================
--- hive/branches/maven/common/src/test/resources/hive-exec-log4j-test.properties (original)
+++ hive/branches/maven/common/src/test/resources/hive-exec-log4j-test.properties Sat Oct  5 03:16:48 2013
@@ -1,6 +1,6 @@
 # Define some default values that can be overridden by system properties
 hive.root.logger=INFO,FA
-hive.log.dir=/tmp
+hive.log.dir=/tmp/TestHiveLogging
 hive.log.file=hiveExecLog4jTest.log
 
 # Define the root logger to the system property "hadoop.root.logger".

Modified: hive/branches/maven/common/src/test/resources/hive-log4j-test.properties
URL: http://svn.apache.org/viewvc/hive/branches/maven/common/src/test/resources/hive-log4j-test.properties?rev=1529381&r1=1529380&r2=1529381&view=diff
==============================================================================
--- hive/branches/maven/common/src/test/resources/hive-log4j-test.properties (original)
+++ hive/branches/maven/common/src/test/resources/hive-log4j-test.properties Sat Oct  5 03:16:48 2013
@@ -1,6 +1,6 @@
 # Define some default values that can be overridden by system properties
 hive.root.logger=WARN,DRFA
-hive.log.dir=/tmp
+hive.log.dir=/tmp/TestHiveLogging
 hive.log.file=hiveLog4jTest.log
 
 # Define the root logger to the system property "hadoop.root.logger".

Modified: hive/branches/maven/contrib/pom.xml
URL: http://svn.apache.org/viewvc/hive/branches/maven/contrib/pom.xml?rev=1529381&r1=1529380&r2=1529381&view=diff
==============================================================================
--- hive/branches/maven/contrib/pom.xml (original)
+++ hive/branches/maven/contrib/pom.xml Sat Oct  5 03:16:48 2013
@@ -19,7 +19,7 @@
   <parent>
     <groupId>org.apache.hive</groupId>
     <artifactId>hive</artifactId>
-    <version>0.13.0-SNAPSHOT</version>
+    <version>0.99.0-SNAPSHOT</version>
     <relativePath>../pom.xml</relativePath>
   </parent>
 

Added: hive/branches/maven/data/conf/hive-log4j-new.properties
URL: http://svn.apache.org/viewvc/hive/branches/maven/data/conf/hive-log4j-new.properties?rev=1529381&view=auto
==============================================================================
--- hive/branches/maven/data/conf/hive-log4j-new.properties (added)
+++ hive/branches/maven/data/conf/hive-log4j-new.properties Sat Oct  5 03:16:48 2013
@@ -0,0 +1,78 @@
+# Licensed to the Apache Software Foundation (ASF) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The ASF licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
+# Define some default values that can be overridden by system properties
+hive.root.logger=DEBUG,DRFA
+hive.log.dir=${test.tmp.dir}/log/
+hive.log.file=hive.log
+
+# Define the root logger to the system property "hadoop.root.logger".
+log4j.rootLogger=${hive.root.logger}, EventCounter
+
+# Logging Threshold
+log4j.threshhold=WARN
+
+#
+# Daily Rolling File Appender
+#
+
+log4j.appender.DRFA=org.apache.log4j.DailyRollingFileAppender
+log4j.appender.DRFA.File=${hive.log.dir}/${hive.log.file}
+
+# Rollver at midnight
+log4j.appender.DRFA.DatePattern=.yyyy-MM-dd
+
+# 30-day backup
+#log4j.appender.DRFA.MaxBackupIndex=30
+log4j.appender.DRFA.layout=org.apache.log4j.PatternLayout
+
+# Pattern format: Date LogLevel LoggerName LogMessage
+#log4j.appender.DRFA.layout.ConversionPattern=%d{ISO8601} %p %c: %m%n
+# Debugging Pattern format
+log4j.appender.DRFA.layout.ConversionPattern=%d{ISO8601} %-5p %c{2} (%F:%M(%L)) - %m%n
+
+
+#
+# console
+# Add "console" to rootlogger above if you want to use this 
+#
+
+log4j.appender.console=org.apache.log4j.ConsoleAppender
+log4j.appender.console.target=System.err
+log4j.appender.console.layout=org.apache.log4j.PatternLayout
+log4j.appender.console.layout.ConversionPattern=%d{yy/MM/dd HH:mm:ss} %p %c{2}: %m%n
+
+#custom logging levels
+#log4j.logger.xxx=DEBUG
+
+#
+# Event Counter Appender
+# Sends counts of logging messages at different severity levels to Hadoop Metrics.
+#
+log4j.appender.EventCounter=org.apache.hadoop.hive.shims.HiveEventCounter
+
+
+log4j.category.DataNucleus=ERROR,DRFA
+log4j.category.Datastore=ERROR,DRFA
+log4j.category.Datastore.Schema=ERROR,DRFA
+log4j.category.JPOX.Datastore=ERROR,DRFA
+log4j.category.JPOX.Plugin=ERROR,DRFA
+log4j.category.JPOX.MetaData=ERROR,DRFA
+log4j.category.JPOX.Query=ERROR,DRFA
+log4j.category.JPOX.General=ERROR,DRFA
+log4j.category.JPOX.Enhancer=ERROR,DRFA
+log4j.logger.org.apache.hadoop.conf.Configuration=ERROR,DRFA
+

Added: hive/branches/maven/data/conf/hive-site-new.xml
URL: http://svn.apache.org/viewvc/hive/branches/maven/data/conf/hive-site-new.xml?rev=1529381&view=auto
==============================================================================
--- hive/branches/maven/data/conf/hive-site-new.xml (added)
+++ hive/branches/maven/data/conf/hive-site-new.xml Sat Oct  5 03:16:48 2013
@@ -0,0 +1,184 @@
+<?xml version="1.0"?>
+<?xml-stylesheet type="text/xsl" href="configuration.xsl"?>
+<!--
+   Licensed to the Apache Software Foundation (ASF) under one or more
+   contributor license agreements.  See the NOTICE file distributed with
+   this work for additional information regarding copyright ownership.
+   The ASF licenses this file to You under the Apache License, Version 2.0
+   (the "License"); you may not use this file except in compliance with
+   the License.  You may obtain a copy of the License at
+
+       http://www.apache.org/licenses/LICENSE-2.0
+
+   Unless required by applicable law or agreed to in writing, software
+   distributed under the License is distributed on an "AS IS" BASIS,
+   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+   See the License for the specific language governing permissions and
+   limitations under the License.
+-->
+
+<configuration>
+
+<!-- Hive Configuration can either be stored in this file or in the hadoop configuration files  -->
+<!-- that are implied by Hadoop setup variables.                                                -->
+<!-- Aside from Hadoop setup variables - this file is provided as a convenience so that Hive    -->
+<!-- users do not have to edit hadoop configuration files (that may be managed as a centralized -->
+<!-- resource).                                                                                 -->
+
+<!-- Hive Execution Parameters -->
+<property>
+  <name>hadoop.tmp.dir</name>
+  <value>${test.tmp.dir}/hadoop-tmp</value>
+  <description>A base for other temporary directories.</description>
+</property>
+
+<!--
+<property>
+  <name>hive.exec.reducers.max</name>
+  <value>1</value>
+  <description>maximum number of reducers</description>
+</property>
+-->
+
+<property>
+  <name>hive.exec.scratchdir</name>
+  <value>${test.tmp.dir}/scratchdir</value>
+  <description>Scratch space for Hive jobs</description>
+</property>
+
+<property>
+  <name>hive.exec.local.scratchdir</name>
+  <value>${test.tmp.dir}/localscratchdir/</value>
+  <description>Local scratch space for Hive jobs</description>
+</property>
+
+<property>
+  <name>javax.jdo.option.ConnectionURL</name>
+  <!-- note: variable substituion not working here because it's loaded by jdo, not Hive -->
+  <value>jdbc:derby:;databaseName=${test.tmp.dir}/junit_metastore_db;create=true</value>
+</property>
+
+<property>
+  <name>javax.jdo.option.ConnectionDriverName</name>
+  <value>org.apache.derby.jdbc.EmbeddedDriver</value>
+</property>
+
+<property>
+  <name>javax.jdo.option.ConnectionUserName</name>
+  <value>APP</value>
+</property>
+
+<property>
+  <name>javax.jdo.option.ConnectionPassword</name>
+  <value>mine</value>
+</property>
+
+<property>
+  <!--  this should eventually be deprecated since the metastore should supply this -->
+  <name>hive.metastore.warehouse.dir</name>
+  <value>${test.tmp.dir}/warehouse</value>
+  <description></description>
+</property>
+
+<property>
+  <name>hive.metastore.metadb.dir</name>
+  <value>file://${test.tmp.dir}/metadb/</value>
+  <description>
+  Required by metastore server or if the uris argument below is not supplied
+  </description>
+</property>
+
+<property>
+  <name>test.log.dir</name>
+  <value>${test.tmp.dir}/log/</value>
+  <description></description>
+</property>
+
+<property>
+  <name>test.data.files</name>
+  <value>${user.dir}/../data/files</value>
+  <description></description>
+</property>
+
+<property>
+  <name>hive.jar.path</name>
+  <value>${user.home}/.m2/repository/org/apache/hive/hive-exec/${project.version}/hive-exec-${project.version}.jar</value>
+  <description></description>
+</property>
+
+<property>
+  <name>hive.metastore.rawstore.impl</name>
+  <value>org.apache.hadoop.hive.metastore.ObjectStore</value>
+  <description>Name of the class that implements org.apache.hadoop.hive.metastore.rawstore interface. This class is used to store and retrieval of raw metadata objects such as table, database</description>
+</property>
+
+<property>
+  <name>hive.querylog.location</name>
+  <value>${test.tmp.dir}/tmp</value>
+  <description>Location of the structured hive logs</description>
+</property>
+
+<property>
+  <name>hive.exec.pre.hooks</name>
+  <value>org.apache.hadoop.hive.ql.hooks.PreExecutePrinter, org.apache.hadoop.hive.ql.hooks.EnforceReadOnlyTables</value>
+  <description>Pre Execute Hook for Tests</description>
+</property>
+
+<property>
+  <name>hive.exec.post.hooks</name>
+  <value>org.apache.hadoop.hive.ql.hooks.PostExecutePrinter</value>
+  <description>Post Execute Hook for Tests</description>
+</property>
+
+<property>
+  <name>hive.task.progress</name>
+  <value>false</value>
+  <description>Track progress of a task</description>
+</property>
+
+<property>
+  <name>hive.support.concurrency</name>
+  <value>true</value>
+  <description>Whether hive supports concurrency or not. A zookeeper instance must be up and running for the default hive lock manager to support read-write locks.</description>
+</property>
+
+<property>
+  <name>fs.pfile.impl</name>
+  <value>org.apache.hadoop.fs.ProxyLocalFileSystem</value>
+  <description>A proxy for local file system used for cross file system testing</description>
+</property>
+
+<property>
+  <name>hive.exec.mode.local.auto</name>
+  <value>false</value>
+  <description>
+    Let hive determine whether to run in local mode automatically
+    Disabling this for tests so that minimr is not affected
+  </description>
+</property>
+
+<property>
+  <name>hive.auto.convert.join</name>
+  <value>false</value>
+  <description>Whether Hive enable the optimization about converting common join into mapjoin based on the input file size</description>
+</property>
+
+<property>
+  <name>hive.ignore.mapjoin.hint</name>
+  <value>false</value>
+  <description>Whether Hive ignores the mapjoin hint</description>
+</property>
+
+<property>
+  <name>hive.input.format</name>
+  <value>org.apache.hadoop.hive.ql.io.CombineHiveInputFormat</value>
+  <description>The default input format, if it is not specified, the system assigns it. It is set to HiveInputFormat for hadoop versions 17, 18 and 19, whereas it is set to CombineHiveInputFormat for hadoop 20. The user can always overwrite it - if there is a bug in CombineHiveInputFormat, it can always be manually set to HiveInputFormat. </description>
+</property>
+
+<property>
+  <name>hive.default.rcfile.serde</name>
+  <value>org.apache.hadoop.hive.serde2.columnar.ColumnarSerDe</value>
+  <description>The default SerDe hive will use for the rcfile format</description>
+</property>
+
+</configuration>

Modified: hive/branches/maven/hbase-handler/pom.xml
URL: http://svn.apache.org/viewvc/hive/branches/maven/hbase-handler/pom.xml?rev=1529381&r1=1529380&r2=1529381&view=diff
==============================================================================
--- hive/branches/maven/hbase-handler/pom.xml (original)
+++ hive/branches/maven/hbase-handler/pom.xml Sat Oct  5 03:16:48 2013
@@ -19,7 +19,7 @@
   <parent>
     <groupId>org.apache.hive</groupId>
     <artifactId>hive</artifactId>
-    <version>0.13.0-SNAPSHOT</version>
+    <version>0.99.0-SNAPSHOT</version>
     <relativePath>../pom.xml</relativePath>
   </parent>
 

Modified: hive/branches/maven/hcatalog/core/pom-new.xml
URL: http://svn.apache.org/viewvc/hive/branches/maven/hcatalog/core/pom-new.xml?rev=1529381&r1=1529380&r2=1529381&view=diff
==============================================================================
--- hive/branches/maven/hcatalog/core/pom-new.xml (original)
+++ hive/branches/maven/hcatalog/core/pom-new.xml Sat Oct  5 03:16:48 2013
@@ -25,7 +25,7 @@
   <parent>
     <groupId>org.apache.hive.hcatalog</groupId>
     <artifactId>hcatalog</artifactId>
-    <version>0.13.0-SNAPSHOT</version>
+    <version>0.99.0-SNAPSHOT</version>
     <relativePath>../pom.xml</relativePath>
   </parent>
 

Modified: hive/branches/maven/hcatalog/hcatalog-pig-adapter/pom-new.xml
URL: http://svn.apache.org/viewvc/hive/branches/maven/hcatalog/hcatalog-pig-adapter/pom-new.xml?rev=1529381&r1=1529380&r2=1529381&view=diff
==============================================================================
--- hive/branches/maven/hcatalog/hcatalog-pig-adapter/pom-new.xml (original)
+++ hive/branches/maven/hcatalog/hcatalog-pig-adapter/pom-new.xml Sat Oct  5 03:16:48 2013
@@ -25,7 +25,7 @@
   <parent>
     <groupId>org.apache.hive.hcatalog</groupId>
     <artifactId>hcatalog</artifactId>
-    <version>0.13.0-SNAPSHOT</version>
+    <version>0.99.0-SNAPSHOT</version>
     <relativePath>../pom.xml</relativePath>
   </parent>
 

Modified: hive/branches/maven/hcatalog/pom-new.xml
URL: http://svn.apache.org/viewvc/hive/branches/maven/hcatalog/pom-new.xml?rev=1529381&r1=1529380&r2=1529381&view=diff
==============================================================================
--- hive/branches/maven/hcatalog/pom-new.xml (original)
+++ hive/branches/maven/hcatalog/pom-new.xml Sat Oct  5 03:16:48 2013
@@ -24,7 +24,7 @@
   <parent>
     <groupId>org.apache.hive</groupId>
     <artifactId>hive</artifactId>
-    <version>0.13.0-SNAPSHOT</version>
+    <version>0.99.0-SNAPSHOT</version>
     <relativePath>../pom.xml</relativePath>
   </parent>
 

Modified: hive/branches/maven/hcatalog/server-extensions/pom-new.xml
URL: http://svn.apache.org/viewvc/hive/branches/maven/hcatalog/server-extensions/pom-new.xml?rev=1529381&r1=1529380&r2=1529381&view=diff
==============================================================================
--- hive/branches/maven/hcatalog/server-extensions/pom-new.xml (original)
+++ hive/branches/maven/hcatalog/server-extensions/pom-new.xml Sat Oct  5 03:16:48 2013
@@ -25,7 +25,7 @@
   <parent>
     <groupId>org.apache.hive.hcatalog</groupId>
     <artifactId>hcatalog</artifactId>
-    <version>0.13.0-SNAPSHOT</version>
+    <version>0.99.0-SNAPSHOT</version>
     <relativePath>../pom.xml</relativePath>
   </parent>
 
@@ -61,6 +61,12 @@
     </dependency>
     <!-- test inter-project -->
     <dependency>
+      <groupId>junit</groupId>
+      <artifactId>junit</artifactId>
+      <version>${junit.version}</version>
+      <scope>test</scope>
+    </dependency>
+    <dependency>
       <groupId>org.apache.activemq</groupId>
       <artifactId>activemq-core</artifactId>
       <version>${activemq.version}</version>

Modified: hive/branches/maven/hcatalog/storage-handlers/hbase/pom-new.xml
URL: http://svn.apache.org/viewvc/hive/branches/maven/hcatalog/storage-handlers/hbase/pom-new.xml?rev=1529381&r1=1529380&r2=1529381&view=diff
==============================================================================
--- hive/branches/maven/hcatalog/storage-handlers/hbase/pom-new.xml (original)
+++ hive/branches/maven/hcatalog/storage-handlers/hbase/pom-new.xml Sat Oct  5 03:16:48 2013
@@ -25,7 +25,7 @@
   <parent>
   <groupId>org.apache.hive.hcatalog</groupId>
   <artifactId>hcatalog</artifactId>
-  <version>0.13.0-SNAPSHOT</version>
+  <version>0.99.0-SNAPSHOT</version>
   <relativePath>../../pom.xml</relativePath>
   </parent>
 

Modified: hive/branches/maven/hcatalog/webhcat/java-client/pom-new.xml
URL: http://svn.apache.org/viewvc/hive/branches/maven/hcatalog/webhcat/java-client/pom-new.xml?rev=1529381&r1=1529380&r2=1529381&view=diff
==============================================================================
--- hive/branches/maven/hcatalog/webhcat/java-client/pom-new.xml (original)
+++ hive/branches/maven/hcatalog/webhcat/java-client/pom-new.xml Sat Oct  5 03:16:48 2013
@@ -25,7 +25,7 @@
   <parent>
     <groupId>org.apache.hive.hcatalog</groupId>
     <artifactId>hcatalog</artifactId>
-    <version>0.13.0-SNAPSHOT</version>
+    <version>0.99.0-SNAPSHOT</version>
     <relativePath>../../pom.xml</relativePath>
   </parent>
 

Modified: hive/branches/maven/hcatalog/webhcat/svr/pom-new.xml
URL: http://svn.apache.org/viewvc/hive/branches/maven/hcatalog/webhcat/svr/pom-new.xml?rev=1529381&r1=1529380&r2=1529381&view=diff
==============================================================================
--- hive/branches/maven/hcatalog/webhcat/svr/pom-new.xml (original)
+++ hive/branches/maven/hcatalog/webhcat/svr/pom-new.xml Sat Oct  5 03:16:48 2013
@@ -25,7 +25,7 @@
   <parent>
     <groupId>org.apache.hive.hcatalog</groupId>
     <artifactId>hcatalog</artifactId>
-    <version>0.13.0-SNAPSHOT</version>
+    <version>0.99.0-SNAPSHOT</version>
     <relativePath>../../pom.xml</relativePath>
   </parent>
 

Modified: hive/branches/maven/hwi/pom.xml
URL: http://svn.apache.org/viewvc/hive/branches/maven/hwi/pom.xml?rev=1529381&r1=1529380&r2=1529381&view=diff
==============================================================================
--- hive/branches/maven/hwi/pom.xml (original)
+++ hive/branches/maven/hwi/pom.xml Sat Oct  5 03:16:48 2013
@@ -19,7 +19,7 @@
   <parent>
     <groupId>org.apache.hive</groupId>
     <artifactId>hive</artifactId>
-    <version>0.13.0-SNAPSHOT</version>
+    <version>0.99.0-SNAPSHOT</version>
     <relativePath>../pom.xml</relativePath>
   </parent>
 

Modified: hive/branches/maven/itests/pom.xml
URL: http://svn.apache.org/viewvc/hive/branches/maven/itests/pom.xml?rev=1529381&r1=1529380&r2=1529381&view=diff
==============================================================================
--- hive/branches/maven/itests/pom.xml (original)
+++ hive/branches/maven/itests/pom.xml Sat Oct  5 03:16:48 2013
@@ -19,7 +19,7 @@
   <parent>
     <groupId>org.apache.hive</groupId>
     <artifactId>hive</artifactId>
-    <version>0.13.0-SNAPSHOT</version>
+    <version>0.99.0-SNAPSHOT</version>
     <relativePath>../pom.xml</relativePath>
   </parent>
 
@@ -40,6 +40,7 @@
 
   <dependencies>
     <!-- test intra-project -->
+    <!-- Note: hive-exec packages common, service, thrift, and ql -->
     <dependency>
       <groupId>org.apache.hive</groupId>
       <artifactId>hive-ant</artifactId>
@@ -51,30 +52,96 @@
       <artifactId>hive-cli</artifactId>
       <version>${project.version}</version>
       <scope>test</scope>
-    </dependency>
-    <dependency>
-      <groupId>org.apache.hive</groupId>
-      <artifactId>hive-common</artifactId>
-      <version>${project.version}</version>
-      <scope>test</scope>
+      <exclusions>
+        <exclusion>
+          <groupId>org.apache.hive</groupId>
+          <artifactId>hive-common</artifactId>
+        </exclusion>
+        <exclusion>
+          <groupId>org.apache.hive</groupId>
+          <artifactId>hive-serde</artifactId>
+        </exclusion>
+        <exclusion>
+          <groupId>org.apache.hive</groupId>
+          <artifactId>hive-thrift</artifactId>
+        </exclusion>
+        <exclusion>
+          <groupId>org.apache.hive</groupId>
+          <artifactId>hive-ql</artifactId>
+        </exclusion>
+      </exclusions> 
     </dependency>
     <dependency>
       <groupId>org.apache.hive</groupId>
       <artifactId>hive-hbase-handler</artifactId>
       <version>${project.version}</version>
       <scope>test</scope>
+      <exclusions>
+        <exclusion>
+          <groupId>org.apache.hive</groupId>
+          <artifactId>hive-common</artifactId>
+        </exclusion>
+        <exclusion>
+          <groupId>org.apache.hive</groupId>
+          <artifactId>hive-serde</artifactId>
+        </exclusion>
+        <exclusion>
+          <groupId>org.apache.hive</groupId>
+          <artifactId>hive-thrift</artifactId>
+        </exclusion>
+        <exclusion>
+          <groupId>org.apache.hive</groupId>
+          <artifactId>hive-ql</artifactId>
+        </exclusion>
+      </exclusions> 
     </dependency>
     <dependency>
       <groupId>org.apache.hive</groupId>
       <artifactId>hive-jdbc</artifactId>
       <version>${project.version}</version>
       <scope>test</scope>
+      <exclusions>
+        <exclusion>
+          <groupId>org.apache.hive</groupId>
+          <artifactId>hive-common</artifactId>
+        </exclusion>
+        <exclusion>
+          <groupId>org.apache.hive</groupId>
+          <artifactId>hive-serde</artifactId>
+        </exclusion>
+        <exclusion>
+          <groupId>org.apache.hive</groupId>
+          <artifactId>hive-thrift</artifactId>
+        </exclusion>
+        <exclusion>
+          <groupId>org.apache.hive</groupId>
+          <artifactId>hive-ql</artifactId>
+        </exclusion>
+      </exclusions> 
     </dependency>
     <dependency>
       <groupId>org.apache.hive</groupId>
       <artifactId>hive-metastore</artifactId>
       <version>${project.version}</version>
       <scope>test</scope>
+      <exclusions>
+        <exclusion>
+          <groupId>org.apache.hive</groupId>
+          <artifactId>hive-common</artifactId>
+        </exclusion>
+        <exclusion>
+          <groupId>org.apache.hive</groupId>
+          <artifactId>hive-serde</artifactId>
+        </exclusion>
+        <exclusion>
+          <groupId>org.apache.hive</groupId>
+          <artifactId>hive-thrift</artifactId>
+        </exclusion>
+        <exclusion>
+          <groupId>org.apache.hive</groupId>
+          <artifactId>hive-ql</artifactId>
+        </exclusion>
+      </exclusions> 
     </dependency>
     <dependency>
       <groupId>org.apache.hive</groupId>
@@ -82,18 +149,48 @@
       <version>${project.version}</version>
       <scope>test</scope>
       <classifier>tests</classifier>
-    </dependency>
-    <dependency>
-      <groupId>org.apache.hive</groupId>
-      <artifactId>hive-serde</artifactId>
-      <version>${project.version}</version>
-      <scope>test</scope>
+      <exclusions>
+        <exclusion>
+          <groupId>org.apache.hive</groupId>
+          <artifactId>hive-common</artifactId>
+        </exclusion>
+        <exclusion>
+          <groupId>org.apache.hive</groupId>
+          <artifactId>hive-serde</artifactId>
+        </exclusion>
+        <exclusion>
+          <groupId>org.apache.hive</groupId>
+          <artifactId>hive-thrift</artifactId>
+        </exclusion>
+        <exclusion>
+          <groupId>org.apache.hive</groupId>
+          <artifactId>hive-ql</artifactId>
+        </exclusion>
+      </exclusions> 
     </dependency>
     <dependency>
       <groupId>org.apache.hive</groupId>
       <artifactId>hive-service</artifactId>
       <version>${project.version}</version>
       <scope>test</scope>
+      <exclusions>
+        <exclusion>
+          <groupId>org.apache.hive</groupId>
+          <artifactId>hive-common</artifactId>
+        </exclusion>
+        <exclusion>
+          <groupId>org.apache.hive</groupId>
+          <artifactId>hive-serde</artifactId>
+        </exclusion>
+        <exclusion>
+          <groupId>org.apache.hive</groupId>
+          <artifactId>hive-thrift</artifactId>
+        </exclusion>
+        <exclusion>
+          <groupId>org.apache.hive</groupId>
+          <artifactId>hive-ql</artifactId>
+        </exclusion>
+      </exclusions> 
     </dependency>
     <dependency>
       <groupId>org.apache.hive</groupId>
@@ -101,6 +198,24 @@
       <version>${project.version}</version>
       <scope>test</scope>
       <classifier>tests</classifier>
+      <exclusions>
+        <exclusion>
+          <groupId>org.apache.hive</groupId>
+          <artifactId>hive-common</artifactId>
+        </exclusion>
+        <exclusion>
+          <groupId>org.apache.hive</groupId>
+          <artifactId>hive-serde</artifactId>
+        </exclusion>
+        <exclusion>
+          <groupId>org.apache.hive</groupId>
+          <artifactId>hive-thrift</artifactId>
+        </exclusion>
+        <exclusion>
+          <groupId>org.apache.hive</groupId>
+          <artifactId>hive-ql</artifactId>
+        </exclusion>
+      </exclusions> 
     </dependency>
     <dependency>
       <groupId>org.apache.hive</groupId>
@@ -108,10 +223,28 @@
       <version>${project.version}</version>
       <scope>test</scope>
       <classifier>tests</classifier>
+      <exclusions>
+        <exclusion>
+          <groupId>org.apache.hive</groupId>
+          <artifactId>hive-common</artifactId>
+        </exclusion>
+        <exclusion>
+          <groupId>org.apache.hive</groupId>
+          <artifactId>hive-serde</artifactId>
+        </exclusion>
+        <exclusion>
+          <groupId>org.apache.hive</groupId>
+          <artifactId>hive-thrift</artifactId>
+        </exclusion>
+        <exclusion>
+          <groupId>org.apache.hive</groupId>
+          <artifactId>hive-ql</artifactId>
+        </exclusion>
+      </exclusions> 
     </dependency>
     <dependency>
       <groupId>org.apache.hive</groupId>
-      <artifactId>hive-ql</artifactId>
+      <artifactId>hive-exec</artifactId>
       <version>${project.version}</version>
       <scope>test</scope>
     </dependency>
@@ -200,24 +333,6 @@
   <build>
     <plugins>
       <plugin>
-        <groupId>org.codehaus.mojo</groupId>
-        <artifactId>build-helper-maven-plugin</artifactId>
-        <executions>
-          <execution>
-            <id>add-test-sources</id>
-            <phase>generate-test-sources</phase>
-            <goals>
-              <goal>add-test-source</goal>
-            </goals>
-            <configuration>
-              <sources>
-                <source>target/generated-test-sources/java</source>
-              </sources>
-            </configuration>
-          </execution>
-        </executions>
-      </plugin>
-      <plugin>
         <groupId>org.apache.maven.plugins</groupId>
         <artifactId>maven-antrun-plugin</artifactId>
         <executions>
@@ -275,7 +390,7 @@
                   queryFileRegex="${qfile_regex}"
                   clusterMode="${clustermode}"
                   runDisabled="${run_disabled}"
-                  resultsDirectory="${basedir}/../ql/src/test/queries/clientpositive/" className="TestCliDriver"
+                  resultsDirectory="${basedir}/../ql/src/test/results/clientpositive/" className="TestCliDriver"
                   logFile="${project.build.directory}/testclidrivergen.log"
                   logDirectory="${project.build.directory}/qfile-results/clientpositive/"
                   hadoopVersion="${active.hadoop.version}"/>
@@ -290,7 +405,7 @@
                   queryFileRegex="${qfile_regex}"
                   clusterMode="${clustermode}"
                   runDisabled="${run_disabled}"
-                  resultsDirectory="${basedir}/../ql/src/test/queries/clientnegative/" className="TestNegativeCliDriver"
+                  resultsDirectory="${basedir}/../ql/src/test/results/clientnegative/" className="TestNegativeCliDriver"
                   logFile="${project.build.directory}/testnegativeclidrivergen.log"
                   logDirectory="${project.build.directory}/qfile-results/clientnegative/"
                   hadoopVersion="${active.hadoop.version}"/>
@@ -305,7 +420,7 @@
                   queryFileRegex="${qfile_regex}"
                   clusterMode="miniMR"
                   runDisabled="${run_disabled}"
-                  resultsDirectory="${basedir}/../ql/src/test/queries/clientpositive/" className="TestMinimrCliDriver"
+                  resultsDirectory="${basedir}/../ql/src/test/results/clientpositive/" className="TestMinimrCliDriver"
                   logFile="${project.build.directory}/testminimrclidrivergen.log"
                   logDirectory="${project.build.directory}/qfile-results/clientpositive/"
                   hadoopVersion="${hadoopVersion}"
@@ -321,7 +436,7 @@
                   queryFileRegex="${qfile_regex}"
                   clusterMode="miniMR"
                   runDisabled="${run_disabled}"
-                  resultsDirectory="${basedir}/../ql/src/test/queries/clientnegative/" className="TestNegativeMinimrCliDriver"
+                  resultsDirectory="${basedir}/../ql/src/test/results/clientnegative/" className="TestNegativeMinimrCliDriver"
                   logFile="${project.build.directory}/testnegativeminimrclidrivergen.log"
                   logDirectory="${project.build.directory}/qfile-results/clientnegative/"
                   hadoopVersion="${hadoopVersion}"
@@ -377,7 +492,7 @@
                         queryFileRegex="${qfile_regex}"
                         clusterMode="${clustermode}"
                         runDisabled="${run_disabled}"
-                        resultsDirectory="${basedir}/../ql/src/test/queries/clientpositive/" className="TestBeeLineDriver"
+                        resultsDirectory="${basedir}/../ql/src/test/results/clientpositive/" className="TestBeeLineDriver"
                         logFile="${project.build.directory}/testbeelinedrivergen.log"
                         logDirectory="${project.build.directory}/qfile-results/beelinepositive/"
                         hadoopVersion="${hadoopVersion}" />
@@ -391,6 +506,24 @@
           </execution>
         </executions>
       </plugin>
+      <plugin>
+        <groupId>org.codehaus.mojo</groupId>
+        <artifactId>build-helper-maven-plugin</artifactId>
+        <executions>
+          <execution>
+            <id>add-test-sources</id>
+            <phase>generate-test-sources</phase>
+            <goals>
+              <goal>add-test-source</goal>
+            </goals>
+            <configuration>
+              <sources>
+                <source>target/generated-test-sources/java</source>
+              </sources>
+            </configuration>
+          </execution>
+        </executions>
+      </plugin>
     </plugins>
   </build>
 

Modified: hive/branches/maven/jdbc/pom.xml
URL: http://svn.apache.org/viewvc/hive/branches/maven/jdbc/pom.xml?rev=1529381&r1=1529380&r2=1529381&view=diff
==============================================================================
--- hive/branches/maven/jdbc/pom.xml (original)
+++ hive/branches/maven/jdbc/pom.xml Sat Oct  5 03:16:48 2013
@@ -19,7 +19,7 @@
   <parent>
     <groupId>org.apache.hive</groupId>
     <artifactId>hive</artifactId>
-    <version>0.13.0-SNAPSHOT</version>
+    <version>0.99.0-SNAPSHOT</version>
     <relativePath>../pom.xml</relativePath>
   </parent>
 
@@ -65,13 +65,6 @@
       <artifactId>libthrift</artifactId>
       <version>${libthrift.version}</version>
     </dependency>
-    <!-- test inter-project -->
-    <dependency>
-      <groupId>junit</groupId>
-      <artifactId>junit</artifactId>
-      <version>${junit.version}</version>
-      <scope>test</scope>
-    </dependency>
   </dependencies>
 
   <profiles>
@@ -105,7 +98,6 @@
 
   <build>
     <sourceDirectory>${basedir}/src/java</sourceDirectory>
-    <testSourceDirectory>${basedir}/src/test</testSourceDirectory>
   </build>
 
 </project>

Modified: hive/branches/maven/maven-rollback.sh
URL: http://svn.apache.org/viewvc/hive/branches/maven/maven-rollback.sh?rev=1529381&r1=1529380&r2=1529381&view=diff
==============================================================================
--- hive/branches/maven/maven-rollback.sh (original)
+++ hive/branches/maven/maven-rollback.sh Sat Oct  5 03:16:48 2013
@@ -6,9 +6,6 @@ move_source() {
   mkdir -p $(dirname $target)
   mv $source $target
 }
-# Generated by: 
-# egrep '^move_source ' maven-rollforward.sh | while read ignore source target; do echo move_source $target $source;done
-# Then reversing order of hcatalog pom moves
 move_source itests/src/test/java/org/apache/hadoop/hive/serde2/TestSerdeWithFieldComments.java serde/src/test/org/apache/hadoop/hive/serde2/TestSerdeWithFieldComments.java
 move_source itests/src/test/java/org/apache/hadoop/hive/serde2/dynamic_type/TestDynamicSerDe.java serde/src/test/org/apache/hadoop/hive/serde2/dynamic_type/TestDynamicSerDe.java
 move_source itests/src/test/java/org/apache/hive/service/cli/thrift/TestThriftHttpCLIService.java service/src/test/org/apache/hive/service/cli/thrift/TestThriftHttpCLIService.java
@@ -29,10 +26,10 @@ move_source itests/src/test/java/org/apa
 move_source itests/src/test/java/org/apache/hadoop/hive/metastore/TestSetUGIOnOnlyServer.java metastore/src/test/org/apache/hadoop/hive/metastore/TestSetUGIOnOnlyServer.java
 move_source itests/src/test/java/org/apache/hadoop/hive/metastore/TestSetUGIOnOnlyClient.java metastore/src/test/org/apache/hadoop/hive/metastore/TestSetUGIOnOnlyClient.java
 move_source itests/src/test/java/org/apache/hadoop/hive/metastore/TestMetastoreVersion.java metastore/src/test/org/apache/hadoop/hive/metastore/TestMetastoreVersion.java
-move_source itests/src/test/java/org/apache/hadoop/ql/security/TestDefaultHiveMetastoreAuthorizationProvider.java ql/src/test/org/apache/hadoop/hive/ql/security/TestDefaultHiveMetastoreAuthorizationProvider.java
-move_source itests/src/test/java/org/apache/hadoop/ql/security/TestAuthorizationPreEventListener.java ql/src/test/org/apache/hadoop/hive/ql/security/TestAuthorizationPreEventListener.java
-move_source itests/src/test/java/org/apache/hadoop/ql/history/TestHiveHistory.java ql/src/test/org/apache/hadoop/hive/ql/history/TestHiveHistory.java
-move_source itests/src/test/java/org/apache/hadoop/ql/QTestUtil.java ql/src/test/org/apache/hadoop/hive/ql/QTestUtil.java
+move_source itests/src/test/java/org/apache/hadoop/hive/ql/security/TestDefaultHiveMetastoreAuthorizationProvider.java ql/src/test/org/apache/hadoop/hive/ql/security/TestDefaultHiveMetastoreAuthorizationProvider.java
+move_source itests/src/test/java/org/apache/hadoop/hive/ql/security/TestAuthorizationPreEventListener.java ql/src/test/org/apache/hadoop/hive/ql/security/TestAuthorizationPreEventListener.java
+move_source itests/src/test/java/org/apache/hadoop/hive/ql/history/TestHiveHistory.java ql/src/test/org/apache/hadoop/hive/ql/history/TestHiveHistory.java
+move_source itests/src/test/java/org/apache/hadoop/hive/ql/QTestUtil.java ql/src/test/org/apache/hadoop/hive/ql/QTestUtil.java
 move_source itests/src/test/java/org/apache/hive/service/server/TestHiveServer2Concurrency.java service/src/test/org/apache/hive/service/server/TestHiveServer2Concurrency.java
 move_source itests/src/test/java/org/apache/hadoop/hive/ql/hooks/EnforceReadOnlyTables.java ql/src/test/org/apache/hadoop/hive/ql/hooks/EnforceReadOnlyTables.java
 move_source itests/src/test/java/org/apache/hadoop/hive/ql/TestMTQueries.java ql/src/test/org/apache/hadoop/hive/ql/TestMTQueries.java
@@ -55,3 +52,25 @@ move_source hcatalog/server-extensions/p
 move_source hcatalog/core/pom-old.xml hcatalog/core/pom.xml
 move_source hcatalog/webhcat/java-client/pom-old.xml hcatalog/webhcat/java-client/pom.xml
 move_source hcatalog/webhcat/svr/pom-old.xml hcatalog/webhcat/svr/pom.xml
+
+move_source data/conf/hive-site.xml data/conf/hive-site-new.xml
+move_source data/conf/hive-site-old.xml data/conf/hive-site.xml
+move_source data/conf/hive-log4j.properties data/conf/hive-log4j-new.properties
+move_source data/conf/hive-log4j-old.properties data/conf/hive-log4j.properties
+
+move_source shims/0.20/src/main/java shims/src/0.20/java
+move_source shims/0.20S/src/main/java shims/src/0.20S/java
+move_source shims/0.23/src/main/java shims/src/0.23/java
+move_source shims/common/src/main/java shims/src/common/java
+move_source shims/common-secure/src/main/java shims/src/common-secure/java
+
+move_source itests/src/test/java/org/apache/hadoop/hive/thrift/TestDBTokenStore.java shims/src/common-secure/test/org/apache/hadoop/hive/thrift/TestDBTokenStore.java
+move_source itests/src/test/java/org/apache/hadoop/hive/thrift/TestHadoop20SAuthBridge.java shims/src/common-secure/test/org/apache/hadoop/hive/thrift/TestHadoop20SAuthBridge.java
+move_source itests/src/test/java/org/apache/hadoop/hive/thrift/TestZooKeeperTokenStore.java shims/src/common-secure/test/org/apache/hadoop/hive/thrift/TestZooKeeperTokenStore.java
+
+move_source itests/src/test/java/org/apache/hadoop/hive/jdbc/TestJdbcDriver.java jdbc/src/test/org/apache/hadoop/hive/jdbc/TestJdbcDriver.java
+move_source itests/src/test/java/org/apache/hive/jdbc/TestJdbcDriver2.java jdbc/src/test/org/apache/hive/jdbc/TestJdbcDriver2.java
+
+move_source itests/src/test/java/org/apache/hive/service/cli/TestEmbeddedThriftBinaryCLIService.java service/src/test/org/apache/hive/service/cli/TestEmbeddedThriftBinaryCLIService.java
+move_source itests/src/test/java/org/apache/hive/service/cli/thrift/TestThriftBinaryCLIService.java service/src/test/org/apache/hive/service/cli/thrift/TestThriftBinaryCLIService.java
+move_source itests/src/test/java/org/apache/hadoop/hive/service/TestHiveServer.java service/src/test/org/apache/hadoop/hive/service/TestHiveServer.java

Modified: hive/branches/maven/maven-rollforward.sh
URL: http://svn.apache.org/viewvc/hive/branches/maven/maven-rollforward.sh?rev=1529381&r1=1529380&r2=1529381&view=diff
==============================================================================
--- hive/branches/maven/maven-rollforward.sh (original)
+++ hive/branches/maven/maven-rollforward.sh Sat Oct  5 03:16:48 2013
@@ -25,10 +25,10 @@ move_source metastore/src/test/org/apach
 move_source metastore/src/test/org/apache/hadoop/hive/metastore/TestSetUGIOnOnlyServer.java itests/src/test/java/org/apache/hadoop/hive/metastore/TestSetUGIOnOnlyServer.java
 move_source metastore/src/test/org/apache/hadoop/hive/metastore/TestSetUGIOnOnlyClient.java itests/src/test/java/org/apache/hadoop/hive/metastore/TestSetUGIOnOnlyClient.java
 move_source metastore/src/test/org/apache/hadoop/hive/metastore/TestMetastoreVersion.java itests/src/test/java/org/apache/hadoop/hive/metastore/TestMetastoreVersion.java
-move_source ql/src/test/org/apache/hadoop/hive/ql/security/TestDefaultHiveMetastoreAuthorizationProvider.java itests/src/test/java/org/apache/hadoop/ql/security/TestDefaultHiveMetastoreAuthorizationProvider.java
-move_source ql/src/test/org/apache/hadoop/hive/ql/security/TestAuthorizationPreEventListener.java itests/src/test/java/org/apache/hadoop/ql/security/TestAuthorizationPreEventListener.java
-move_source ql/src/test/org/apache/hadoop/hive/ql/history/TestHiveHistory.java itests/src/test/java/org/apache/hadoop/ql/history/TestHiveHistory.java
-move_source ql/src/test/org/apache/hadoop/hive/ql/QTestUtil.java itests/src/test/java/org/apache/hadoop/ql/QTestUtil.java
+move_source ql/src/test/org/apache/hadoop/hive/ql/security/TestDefaultHiveMetastoreAuthorizationProvider.java itests/src/test/java/org/apache/hadoop/hive/ql/security/TestDefaultHiveMetastoreAuthorizationProvider.java
+move_source ql/src/test/org/apache/hadoop/hive/ql/security/TestAuthorizationPreEventListener.java itests/src/test/java/org/apache/hadoop/hive/ql/security/TestAuthorizationPreEventListener.java
+move_source ql/src/test/org/apache/hadoop/hive/ql/history/TestHiveHistory.java itests/src/test/java/org/apache/hadoop/hive/ql/history/TestHiveHistory.java
+move_source ql/src/test/org/apache/hadoop/hive/ql/QTestUtil.java itests/src/test/java/org/apache/hadoop/hive/ql/QTestUtil.java
 move_source service/src/test/org/apache/hive/service/server/TestHiveServer2Concurrency.java itests/src/test/java/org/apache/hive/service/server/TestHiveServer2Concurrency.java
 move_source ql/src/test/org/apache/hadoop/hive/ql/hooks/EnforceReadOnlyTables.java itests/src/test/java/org/apache/hadoop/hive/ql/hooks/EnforceReadOnlyTables.java
 move_source ql/src/test/org/apache/hadoop/hive/ql/TestMTQueries.java itests/src/test/java/org/apache/hadoop/hive/ql/TestMTQueries.java
@@ -51,3 +51,26 @@ move_source hcatalog/server-extensions/p
 move_source hcatalog/core/pom-new.xml hcatalog/core/pom.xml
 move_source hcatalog/webhcat/java-client/pom-new.xml hcatalog/webhcat/java-client/pom.xml
 move_source hcatalog/webhcat/svr/pom-new.xml hcatalog/webhcat/svr/pom.xml
+
+move_source data/conf/hive-site.xml data/conf/hive-site-old.xml
+move_source data/conf/hive-site-new.xml data/conf/hive-site.xml
+move_source data/conf/hive-log4j.properties data/conf/hive-log4j-old.properties
+move_source data/conf/hive-log4j-new.properties data/conf/hive-log4j.properties
+
+# eclipse doesn't like .. references in it's path to src
+move_source shims/src/0.20/java shims/0.20/src/main/java
+move_source shims/src/0.20S/java shims/0.20S/src/main/java
+move_source shims/src/0.23/java shims/0.23/src/main/java
+move_source shims/src/common/java shims/common/src/main/java
+move_source shims/src/common-secure/java shims/common-secure/src/main/java
+# cyclic deps
+move_source shims/src/common-secure/test/org/apache/hadoop/hive/thrift/TestDBTokenStore.java itests/src/test/java/org/apache/hadoop/hive/thrift/TestDBTokenStore.java
+move_source shims/src/common-secure/test/org/apache/hadoop/hive/thrift/TestHadoop20SAuthBridge.java itests/src/test/java/org/apache/hadoop/hive/thrift/TestHadoop20SAuthBridge.java
+move_source shims/src/common-secure/test/org/apache/hadoop/hive/thrift/TestZooKeeperTokenStore.java itests/src/test/java/org/apache/hadoop/hive/thrift/TestZooKeeperTokenStore.java
+
+move_source jdbc/src/test/org/apache/hadoop/hive/jdbc/TestJdbcDriver.java itests/src/test/java/org/apache/hadoop/hive/jdbc/TestJdbcDriver.java
+move_source jdbc/src/test/org/apache/hive/jdbc/TestJdbcDriver2.java itests/src/test/java/org/apache/hive/jdbc/TestJdbcDriver2.java
+
+move_source service/src/test/org/apache/hive/service/cli/TestEmbeddedThriftBinaryCLIService.java itests/src/test/java/org/apache/hive/service/cli/TestEmbeddedThriftBinaryCLIService.java
+move_source service/src/test/org/apache/hive/service/cli/thrift/TestThriftBinaryCLIService.java itests/src/test/java/org/apache/hive/service/cli/thrift/TestThriftBinaryCLIService.java
+move_source service/src/test/org/apache/hadoop/hive/service/TestHiveServer.java itests/src/test/java/org/apache/hadoop/hive/service/TestHiveServer.java

Modified: hive/branches/maven/metastore/pom.xml
URL: http://svn.apache.org/viewvc/hive/branches/maven/metastore/pom.xml?rev=1529381&r1=1529380&r2=1529381&view=diff
==============================================================================
--- hive/branches/maven/metastore/pom.xml (original)
+++ hive/branches/maven/metastore/pom.xml Sat Oct  5 03:16:48 2013
@@ -19,7 +19,7 @@
   <parent>
     <groupId>org.apache.hive</groupId>
     <artifactId>hive</artifactId>
-    <version>0.13.0-SNAPSHOT</version>
+    <version>0.99.0-SNAPSHOT</version>
     <relativePath>../pom.xml</relativePath>
   </parent>
 

Modified: hive/branches/maven/pom.xml
URL: http://svn.apache.org/viewvc/hive/branches/maven/pom.xml?rev=1529381&r1=1529380&r2=1529381&view=diff
==============================================================================
--- hive/branches/maven/pom.xml (original)
+++ hive/branches/maven/pom.xml Sat Oct  5 03:16:48 2013
@@ -17,7 +17,7 @@
 
   <groupId>org.apache.hive</groupId>
   <artifactId>hive</artifactId>
-  <version>0.13.0-SNAPSHOT</version>
+  <version>0.99.0-SNAPSHOT</version>
   <packaging>pom</packaging>
 
   <name>Hive</name>
@@ -48,6 +48,8 @@
   <properties>
     <project.build.sourceEncoding>UTF-8</project.build.sourceEncoding>
 
+    <hive.path.to.root>..</hive.path.to.root>
+
     <!-- the versions of libraries that we use -->
     <activemq.version>5.5.0</activemq.version>
     <ant.version>1.9.1</ant.version>
@@ -210,6 +212,33 @@
               <version>20020829</version>
             </dependency>
           </dependencies>
+          <executions>
+            <execution>
+              <id>define-classpath</id>
+              <phase>process-resources</phase>
+              <goals>
+                <goal>run</goal>
+              </goals>
+              <configuration>
+                <exportAntProperties>true</exportAntProperties>
+                <target>
+                  <property name="maven.test.classpath" refid="maven.test.classpath"/>
+                </target>
+              </configuration>
+            </execution>
+            <execution>
+              <id>delete-test-tempdir</id>
+              <phase>process-test-resources</phase>
+              <goals>
+                <goal>run</goal>
+              </goals>
+              <configuration>
+                <target>
+                  <delete dir="${project.build.directory}/test-tmp" />
+                </target>
+              </configuration>
+            </execution>
+          </executions>
         </plugin>
         <plugin>
           <groupId>org.apache.maven.plugins</groupId>
@@ -229,16 +258,23 @@
             <redirectTestOutputToFile>true</redirectTestOutputToFile>
             <reuseForks>false</reuseForks>
             <failIfNoTests>false</failIfNoTests>
-            <systemProperties>
-              <property>
-                <name>test.build.resources</name>
-                <value>${project.build.directory}/test-classes</value>
-              </property>
-              <property>
-                <name>test.warehouse.dir</name>
-                <value>${project.build.directory}/test/data/warehouse/</value>
-              </property>
-            </systemProperties>
+            <additionalClasspathElements>
+              <additionalClasspathElement>${basedir}/${hive.path.to.root}/data/conf</additionalClasspathElement>
+              <additionalClasspathElement>${basedir}/${hive.path.to.root}/conf</additionalClasspathElement>
+            </additionalClasspathElements>
+            <environmentVariables>
+              <TZ>US/Pacific</TZ>
+              <LANG>en_US.UTF-8</LANG>
+              <HADOOP_CLASSPATH>${basedir}/${hive.path.to.root}/data/conf:${basedir}/${hive.path.to.root}/conf</HADOOP_CLASSPATH>
+              <HIVE_HADOOP_TEST_CLASSPATH>${maven.test.classpath}</HIVE_HADOOP_TEST_CLASSPATH>
+            </environmentVariables>
+            <systemPropertyVariables>
+              <build.dir>${project.build.directory}</build.dir>
+              <hadoop.bin.path>${basedir}/${hive.path.to.root}/testutils/hadoop</hadoop.bin.path>
+              <hive.version>${project.version}</hive.version>
+              <test.data.dir>${basedir}/${hive.path.to.root}/data/files</test.data.dir>
+              <test.tmp.dir>${project.build.directory}/test-tmp</test.tmp.dir>
+            </systemPropertyVariables>
           </configuration>
         </plugin>
         <plugin>

Modified: hive/branches/maven/ql/pom.xml
URL: http://svn.apache.org/viewvc/hive/branches/maven/ql/pom.xml?rev=1529381&r1=1529380&r2=1529381&view=diff
==============================================================================
--- hive/branches/maven/ql/pom.xml (original)
+++ hive/branches/maven/ql/pom.xml Sat Oct  5 03:16:48 2013
@@ -19,7 +19,7 @@
   <parent>
     <groupId>org.apache.hive</groupId>
     <artifactId>hive</artifactId>
-    <version>0.13.0-SNAPSHOT</version>
+    <version>0.99.0-SNAPSHOT</version>
     <relativePath>../pom.xml</relativePath>
   </parent>
 
@@ -293,8 +293,8 @@
                   <include>org.apache.hive:hive-common</include>
                   <include>org.apache.hive:hive-ql</include>
                   <include>org.apache.hive:hive-serde</include>
-                  <include>org.apache.hive:hive-thrift</include>
                   <include>com.esotericsoftware.kryo:kryo</include>
+                  <include>org.apache.thrift:libthrift</include>
                   <include>commons-lang:commons-lang</include>
                   <include>org.json:json</include>
                   <include>org.apache.avro:arvro-mapred</include>

Modified: hive/branches/maven/ql/src/java/org/apache/hadoop/hive/ql/exec/mr/ExecDriver.java
URL: http://svn.apache.org/viewvc/hive/branches/maven/ql/src/java/org/apache/hadoop/hive/ql/exec/mr/ExecDriver.java?rev=1529381&r1=1529380&r2=1529381&view=diff
==============================================================================
--- hive/branches/maven/ql/src/java/org/apache/hadoop/hive/ql/exec/mr/ExecDriver.java (original)
+++ hive/branches/maven/ql/src/java/org/apache/hadoop/hive/ql/exec/mr/ExecDriver.java Sat Oct  5 03:16:48 2013
@@ -752,8 +752,7 @@ public class ExecDriver extends Task<Map
       if (hadoopLocalMode && (oneProp.equals(hadoopSysDir) || oneProp.equals(hadoopWorkDir))) {
         continue;
       }
-
-      tempConf.set(oneProp, deltaP.getProperty(oneProp));
+      tempConf.set(oneProp, hconf.get(oneProp));
     }
 
     // Multiple concurrent local mode job submissions can cause collisions in

Modified: hive/branches/maven/serde/pom.xml
URL: http://svn.apache.org/viewvc/hive/branches/maven/serde/pom.xml?rev=1529381&r1=1529380&r2=1529381&view=diff
==============================================================================
--- hive/branches/maven/serde/pom.xml (original)
+++ hive/branches/maven/serde/pom.xml Sat Oct  5 03:16:48 2013
@@ -19,7 +19,7 @@
   <parent>
     <groupId>org.apache.hive</groupId>
     <artifactId>hive</artifactId>
-    <version>0.13.0-SNAPSHOT</version>
+    <version>0.99.0-SNAPSHOT</version>
     <relativePath>../pom.xml</relativePath>
   </parent>
 

Modified: hive/branches/maven/service/pom.xml
URL: http://svn.apache.org/viewvc/hive/branches/maven/service/pom.xml?rev=1529381&r1=1529380&r2=1529381&view=diff
==============================================================================
--- hive/branches/maven/service/pom.xml (original)
+++ hive/branches/maven/service/pom.xml Sat Oct  5 03:16:48 2013
@@ -19,7 +19,7 @@
   <parent>
     <groupId>org.apache.hive</groupId>
     <artifactId>hive</artifactId>
-    <version>0.13.0-SNAPSHOT</version>
+    <version>0.99.0-SNAPSHOT</version>
     <relativePath>../pom.xml</relativePath>
   </parent>
 

Modified: hive/branches/maven/shims/0.20/pom.xml
URL: http://svn.apache.org/viewvc/hive/branches/maven/shims/0.20/pom.xml?rev=1529381&r1=1529380&r2=1529381&view=diff
==============================================================================
--- hive/branches/maven/shims/0.20/pom.xml (original)
+++ hive/branches/maven/shims/0.20/pom.xml Sat Oct  5 03:16:48 2013
@@ -19,7 +19,7 @@
   <parent>
     <groupId>org.apache.hive</groupId>
     <artifactId>hive</artifactId>
-    <version>0.13.0-SNAPSHOT</version>
+    <version>0.99.0-SNAPSHOT</version>
     <relativePath>../../pom.xml</relativePath>
   </parent>
 
@@ -60,7 +60,4 @@
       <version>${jetty.version}</version>
     </dependency>
   </dependencies>
-  <build>
-    <sourceDirectory>${basedir}/../src/0.20/java</sourceDirectory>
-  </build>
 </project>

Modified: hive/branches/maven/shims/0.20S/pom.xml
URL: http://svn.apache.org/viewvc/hive/branches/maven/shims/0.20S/pom.xml?rev=1529381&r1=1529380&r2=1529381&view=diff
==============================================================================
--- hive/branches/maven/shims/0.20S/pom.xml (original)
+++ hive/branches/maven/shims/0.20S/pom.xml Sat Oct  5 03:16:48 2013
@@ -19,7 +19,7 @@
   <parent>
     <groupId>org.apache.hive</groupId>
     <artifactId>hive</artifactId>
-    <version>0.13.0-SNAPSHOT</version>
+    <version>0.99.0-SNAPSHOT</version>
     <relativePath>../../pom.xml</relativePath>
   </parent>
 
@@ -55,7 +55,4 @@
       <version>${jetty.version}</version>
     </dependency>
   </dependencies>
-  <build>
-    <sourceDirectory>${basedir}/../src/0.20S/java</sourceDirectory>
-  </build>
 </project>

Modified: hive/branches/maven/shims/0.23/pom.xml
URL: http://svn.apache.org/viewvc/hive/branches/maven/shims/0.23/pom.xml?rev=1529381&r1=1529380&r2=1529381&view=diff
==============================================================================
--- hive/branches/maven/shims/0.23/pom.xml (original)
+++ hive/branches/maven/shims/0.23/pom.xml Sat Oct  5 03:16:48 2013
@@ -19,7 +19,7 @@
   <parent>
     <groupId>org.apache.hive</groupId>
     <artifactId>hive</artifactId>
-    <version>0.13.0-SNAPSHOT</version>
+    <version>0.99.0-SNAPSHOT</version>
     <relativePath>../../pom.xml</relativePath>
   </parent>
 
@@ -84,7 +84,4 @@
       <version>${jetty.version}</version>
     </dependency>
   </dependencies>
-  <build>
-    <sourceDirectory>${basedir}/../src/0.23/java</sourceDirectory>
-  </build>
 </project>

Modified: hive/branches/maven/shims/common-secure/pom.xml
URL: http://svn.apache.org/viewvc/hive/branches/maven/shims/common-secure/pom.xml?rev=1529381&r1=1529380&r2=1529381&view=diff
==============================================================================
--- hive/branches/maven/shims/common-secure/pom.xml (original)
+++ hive/branches/maven/shims/common-secure/pom.xml Sat Oct  5 03:16:48 2013
@@ -19,7 +19,7 @@
   <parent>
     <groupId>org.apache.hive</groupId>
     <artifactId>hive</artifactId>
-    <version>0.13.0-SNAPSHOT</version>
+    <version>0.99.0-SNAPSHOT</version>
     <relativePath>../../pom.xml</relativePath>
   </parent>
 
@@ -81,7 +81,4 @@
       </exclusions>
     </dependency>
   </dependencies>
-  <build>
-    <sourceDirectory>${basedir}/../src/common-secure/java</sourceDirectory>
-  </build>
 </project>

Modified: hive/branches/maven/shims/common/pom.xml
URL: http://svn.apache.org/viewvc/hive/branches/maven/shims/common/pom.xml?rev=1529381&r1=1529380&r2=1529381&view=diff
==============================================================================
--- hive/branches/maven/shims/common/pom.xml (original)
+++ hive/branches/maven/shims/common/pom.xml Sat Oct  5 03:16:48 2013
@@ -19,7 +19,7 @@
   <parent>
     <groupId>org.apache.hive</groupId>
     <artifactId>hive</artifactId>
-    <version>0.13.0-SNAPSHOT</version>
+    <version>0.99.0-SNAPSHOT</version>
     <relativePath>../../pom.xml</relativePath>
   </parent>
 
@@ -58,7 +58,4 @@
       <version>${libthrift.version}</version>
     </dependency>
   </dependencies>
-  <build>
-    <sourceDirectory>${basedir}/../src/common/java</sourceDirectory>
-  </build>
 </project>

Modified: hive/branches/maven/shims/pom.xml
URL: http://svn.apache.org/viewvc/hive/branches/maven/shims/pom.xml?rev=1529381&r1=1529380&r2=1529381&view=diff
==============================================================================
--- hive/branches/maven/shims/pom.xml (original)
+++ hive/branches/maven/shims/pom.xml Sat Oct  5 03:16:48 2013
@@ -19,7 +19,7 @@
   <parent>
     <groupId>org.apache.hive</groupId>
     <artifactId>hive</artifactId>
-    <version>0.13.0-SNAPSHOT</version>
+    <version>0.99.0-SNAPSHOT</version>
     <relativePath>../pom.xml</relativePath>
   </parent>
 

Modified: hive/branches/maven/shims/src/assembly/uberjar.xml
URL: http://svn.apache.org/viewvc/hive/branches/maven/shims/src/assembly/uberjar.xml?rev=1529381&r1=1529380&r2=1529381&view=diff
==============================================================================
--- hive/branches/maven/shims/src/assembly/uberjar.xml (original)
+++ hive/branches/maven/shims/src/assembly/uberjar.xml Sat Oct  5 03:16:48 2013
@@ -10,6 +10,10 @@
       <scope>compile</scope>
       <useProjectArtifact>false</useProjectArtifact>
       <useTransitiveDependencies>false</useTransitiveDependencies>
+      <excludes>
+        <exclude>org.slf4j:slf4j-api</exclude>
+        <exclude>org.slf4j:slf4j-log4j12</exclude>
+      </excludes>
     </dependencySet>
   </dependencySets>
 </assembly>

Modified: hive/branches/maven/testutils/pom.xml
URL: http://svn.apache.org/viewvc/hive/branches/maven/testutils/pom.xml?rev=1529381&r1=1529380&r2=1529381&view=diff
==============================================================================
--- hive/branches/maven/testutils/pom.xml (original)
+++ hive/branches/maven/testutils/pom.xml Sat Oct  5 03:16:48 2013
@@ -19,7 +19,7 @@
   <parent>
     <groupId>org.apache.hive</groupId>
     <artifactId>hive</artifactId>
-    <version>0.13.0-SNAPSHOT</version>
+    <version>0.99.0-SNAPSHOT</version>
     <relativePath>../pom.xml</relativePath>
   </parent>
--- hive/branches/maven/common/src/test/org/apache/hadoop/hive/conf/TestHiveLogging.java (original)
+++ hive/branches/maven/common/src/test/org/apache/hadoop/hive/conf/TestHiveLogging.java Sat Oct  5 03:16:48 2013
@@ -17,16 +17,14 @@
  */
 package org.apache.hadoop.hive.conf;
 
+import java.io.BufferedReader;
+import java.io.InputStreamReader;
+
 import junit.framework.TestCase;
 
-import org.apache.hadoop.conf.Configuration;
-import org.apache.hadoop.hive.conf.HiveConf.ConfVars;
 import org.apache.hadoop.hive.common.LogUtils;
-import org.apache.hadoop.hive.common.LogUtils.LogInitializationException;
-
-import java.io.BufferedReader;
-import java.io.IOException;
-import java.io.InputStreamReader;
+import org.apache.hadoop.hive.conf.HiveConf.ConfVars;
+import org.apache.hive.common.util.HiveTestUtils;
 
 /**
  * TestHiveLogging
@@ -44,53 +42,33 @@ public class TestHiveLogging extends Tes
     process = null;
   }
 
-  private void configLog(String hiveLog4jTest, String hiveExecLog4jTest) {
-    System.out.println("BLA "+ System.getProperty("test.build.resources") );
-    System.setProperty(ConfVars.HIVE_LOG4J_FILE.varname,
-      System.getProperty("test.build.resources") + "/" + hiveLog4jTest);
-    System.setProperty(ConfVars.HIVE_EXEC_LOG4J_FILE.varname,
-      System.getProperty("test.build.resources") + "/" + hiveExecLog4jTest);
-
-    String expectedLog4jPath = System.getProperty("test.build.resources")
-      + "/" + hiveLog4jTest;
-    String expectedLog4jExecPath = System.getProperty("test.build.resources")
-      + "/" + hiveExecLog4jTest;
-
-    try {
-      LogUtils.initHiveLog4j();
-    } catch (LogInitializationException e) {
-    }
+  private void configLog(String hiveLog4jTest, String hiveExecLog4jTest) 
+  throws Exception {
+    String expectedLog4jTestPath = HiveTestUtils.getFileFromClasspath(hiveLog4jTest);
+    String expectedLog4jExecPath = HiveTestUtils.getFileFromClasspath(hiveExecLog4jTest);
+    System.setProperty(ConfVars.HIVE_LOG4J_FILE.varname, expectedLog4jTestPath);
+    System.setProperty(ConfVars.HIVE_EXEC_LOG4J_FILE.varname, expectedLog4jExecPath);
+
+    LogUtils.initHiveLog4j();
 
     HiveConf conf = new HiveConf();
-    assertEquals(expectedLog4jPath, conf.getVar(ConfVars.HIVE_LOG4J_FILE));
+    assertEquals(expectedLog4jTestPath, conf.getVar(ConfVars.HIVE_LOG4J_FILE));
     assertEquals(expectedLog4jExecPath, conf.getVar(ConfVars.HIVE_EXEC_LOG4J_FILE));
   }
 
-  private void runCmd(String cmd) {
-    try {
-      process = runTime.exec(cmd);
-    } catch (IOException e) {
-      e.printStackTrace();
-    }
-    try {
-      process.waitFor();
-    } catch (InterruptedException e) {
-      e.printStackTrace();
-    }
+  private void runCmd(String cmd) throws Exception {
+    process = runTime.exec(cmd);
+    process.waitFor();
   }
 
-  private void getCmdOutput(String logFile) {
+  private void getCmdOutput(String logFile) throws Exception {
     boolean logCreated = false;
     BufferedReader buf = new BufferedReader(
       new InputStreamReader(process.getInputStream()));
     String line = "";
-    try {
-      while((line = buf.readLine()) != null) {
-        if (line.equals(logFile))
-          logCreated = true;
-      }
-    } catch (IOException e) {
-      e.printStackTrace();
+    while((line = buf.readLine()) != null) {
+      if (line.equals(logFile))
+        logCreated = true;
     }
     assertEquals(true, logCreated);
   }
@@ -113,12 +91,12 @@ public class TestHiveLogging extends Tes
   }
 
   public void testHiveLogging() throws Exception {
-    // customized log4j config log file to be: /tmp/hiveLog4jTest.log
-    String customLogPath = "/tmp/";
+    // customized log4j config log file to be: /tmp/TestHiveLogging/hiveLog4jTest.log
+    String customLogPath = "/tmp/TestHiveLogging/";
     String customLogName = "hiveLog4jTest.log";
     String customLogFile = customLogPath + customLogName;
     String customCleanCmd = "rm -rf " + customLogFile;
-    String customFindCmd = "find /tmp -name " + customLogName;
+    String customFindCmd = "find " + customLogPath + " -name " + customLogName;
     RunTest(customCleanCmd, customFindCmd, customLogFile,
       "hive-log4j-test.properties", "hive-exec-log4j-test.properties");
   }

Modified: hive/branches/maven/common/src/test/resources/hive-exec-log4j-test.properties
URL: http://svn.apache.org/viewvc/hive/branches/maven/common/src/test/resources/hive-exec-log4j-test.properties?rev=1529381&r1=1529380&r2=1529381&view=diff
==============================================================================